@@ -771,7 +771,8 @@ gcm_calibrate_is_livecd (void)
 		g_error_free (error);
 		goto out;
 	}
-	ret = g_strstr_len (data, -1, "liveimg") != NULL;
+	ret = (g_strstr_len (data, -1, "liveimg") != NULL ||
+	       g_strstr_len (data, -1, "casper") != NULL);
 out:
 	g_free (data);
 	return ret;
@@ -1734,6 +1735,7 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *calib)
 	g_signal_connect (widget, "toggled",
 			  G_CALLBACK (gcm_calib_precision_toggled_cb), calib);
 	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 
 	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
 	widget = gtk_radio_button_new_with_label (list, labels[2]->str);
@@ -1899,7 +1901,7 @@ gcm_calib_setup_page_failure (GcmCalibratePriv *calib)
 static void
 gcm_calib_got_sensor (GcmCalibratePriv *calib, CdSensor *sensor)
 {
-	gboolean is_photospectrometer = FALSE;
+	gboolean is_lowend = FALSE;
 	gboolean ret;
 	GError *error = NULL;
 	GtkWidget *vbox;
@@ -1922,15 +1924,13 @@ gcm_calib_got_sensor (GcmCalibratePriv *calib, CdSensor *sensor)
 	/* if the device is a simple colorimeter, hide the temperature
 	 * chooser. Only expensive accurate spectrophotometers are
 	 * accurate enough to do a good job without a color cast */
-	if (cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_I1_PRO ||
-	    cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_COLOR_MUNKI ||
-	    cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_I1_DISPLAY3) {
-		is_photospectrometer = TRUE;
+	if (cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_COLORHUG) {
+		is_lowend = TRUE;
 	}
 	if (calib->device_kind == CD_DEVICE_KIND_DISPLAY) {
 		vbox = gcm_calib_get_vbox_for_page (calib,
 						    GCM_CALIBRATE_PAGE_DISPLAY_TEMPERATURE);
-		gtk_widget_set_visible (vbox, is_photospectrometer);
+		gtk_widget_set_visible (vbox, !is_lowend);
 	}
 out:
 	return;
@@ -2052,6 +2052,9 @@ gcm_calib_sensor_added_cb (CdClient *client, CdSensor *sensor, GcmCalibratePriv
 static void
 gcm_calib_startup_cb (GApplication *application, GcmCalibratePriv *calib)
 {
+	const gint window_width  = 640;
+	const gint window_height = 440;
+
 	const gchar *description;
 	const gchar *manufacturer;
 	const gchar *model;
@@ -2082,6 +2085,7 @@ gcm_calib_startup_cb (GApplication *application, GcmCalibratePriv *calib)
 
 	/* show main UI */
 	calib->main_window = GTK_WINDOW (gtk_assistant_new ());
+	gtk_window_set_default_size (calib->main_window, window_width, window_height);
 	gtk_window_set_resizable (calib->main_window, TRUE);
 	gtk_window_set_title (calib->main_window, "");
 	gtk_container_set_border_width (GTK_CONTAINER (calib->main_window), 12);
@@ -2129,6 +2133,14 @@ gcm_calib_startup_cb (GApplication *application, GcmCalibratePriv *calib)
 	/* get the device properties */
 	calib->device_kind = cd_device_get_kind (calib->device);
 
+	/* for display calibration move the window to lower right area to
+         * limit argyll from obscuring the window (too much) */
+	if (calib->device_kind == CD_DEVICE_KIND_DISPLAY) {
+		gtk_window_set_gravity (calib->main_window, GDK_GRAVITY_SOUTH_EAST);
+		gtk_window_move (calib->main_window, gdk_screen_width()  - window_width,
+						     gdk_screen_height() - window_height);
+	}
+
 	/* set, with fallbacks */
 	serial = cd_device_get_serial (calib->device);
 	if (serial == NULL) {
