@@ -1887,8 +1887,6 @@ gcm_calibrate_printer (GcmCalibrate *calibrate, CdDevice *device, GtkWindow *win
 		goto out;
 
 	/* copy */
-	g_object_get (NULL, "print-kind", &priv->print_kind, NULL);
-
 	if (priv->print_kind == GCM_CALIBRATE_PRINT_KIND_ANALYZE) {
 
 		/* remove previously set value (if any) */
@@ -2318,6 +2316,9 @@ gcm_calibrate_set_property (GObject *object, guint prop_id, const GValue *value,
 	case PROP_DISPLAY_KIND:
 		priv->display_kind = g_value_get_uint (value);
 		break;
+	case PROP_PRINT_KIND:
+		priv->print_kind = g_value_get_uint (value);
+		break;
 	case PROP_REFERENCE_KIND:
 		priv->reference_kind = g_value_get_uint (value);
 		break;
@@ -2358,7 +2359,7 @@ gcm_calibrate_class_init (GcmCalibrateClass *klass)
 
 	pspec = g_param_spec_uint ("print-kind", NULL, NULL,
 				   0, G_MAXUINT, 0,
-				   G_PARAM_READABLE);
+				   G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_PRINT_KIND, pspec);
 
 	pspec = g_param_spec_uint ("device-kind", NULL, NULL,
